@@ -665,11 +665,13 @@ loop_rx_exit:
 	return 0;
 }
 
+extern int mtp2_msu_only;
 extern wanpipe_hdlc_engine_t *rx_hdlc_eng;  
 wp_trace_output_iface_t hdlc_trace_iface;
 
 static int trace_aft_hdlc_data(wanpipe_hdlc_engine_t *hdlc_eng, void *data, int len)
 {
+	char *frame = (char*)data;
 	hdlc_trace_iface.data=data;
 	hdlc_trace_iface.len=len;
 
@@ -678,6 +680,12 @@ static int trace_aft_hdlc_data(wanpipe_hdlc_engine_t *hdlc_eng, void *data, int
 	hdlc_trace_iface.sec		= trace_iface.sec;
 	hdlc_trace_iface.usec		= trace_iface.usec;
 
+	if (mtp2_msu_only) {
+		if (frame[2] < 3) {
+			return 1;
+		}
+	}			
+
 	if (pcap_output){
 		hdlc_trace_iface.type=WP_OUT_TRACE_PCAP;
 	} else {
@@ -814,14 +822,11 @@ static void line_trace(int trace_mode)
 				}else
 				*/
 
-#if 1 
 				if (trace_iface.type == WP_OUT_TRACE_HDLC && rx_hdlc_eng) {
-					printf("TRACING HDLC ----> DIR=%i\n",	trace_iface.status);	
 					rx_hdlc_eng->hdlc_data = trace_aft_hdlc_data;
 					wanpipe_hdlc_decode(rx_hdlc_eng,trace_iface.data,trace_iface.len);
 					continue;		
 				} 
-#endif
 				
 			       	if (pcap_output){
 					trace_iface.type=WP_OUT_TRACE_PCAP;
